[Scummvm-git-logs] scummvm master -> f56f91af16640b80fb7416fe2f1f0eadd921f351

bgK bastien.bouclet at gmail.com
Sun Dec 11 09:53:24 CET 2016


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
f56f91af16 MOHAWK: Fix transparency for the rotation cursors in Myst


Commit: f56f91af16640b80fb7416fe2f1f0eadd921f351
    https://github.com/scummvm/scummvm/commit/f56f91af16640b80fb7416fe2f1f0eadd921f351
Author: Bastien Bouclet (bastien.bouclet at gmail.com)
Date: 2016-12-11T09:52:09+01:00

Commit Message:
MOHAWK: Fix transparency for the rotation cursors in Myst

Changed paths:
    engines/mohawk/cursors.cpp


diff --git a/engines/mohawk/cursors.cpp b/engines/mohawk/cursors.cpp
index abc1322..b78f71a 100644
--- a/engines/mohawk/cursors.cpp
+++ b/engines/mohawk/cursors.cpp
@@ -122,8 +122,13 @@ void MystCursorManager::setCursor(uint16 id) {
 	if (surface->format.bytesPerPixel == 1) {
 		// The transparent color is almost always 255, except for the main cursor (100)
 		// in the D'ni archive, where it is 0.
-		// Using the color of the first pixel as the transparent color seems to always work.
-		byte transparentColor = ((byte *)surface->getPixels())[0];
+		// Using the color of the first pixel as the transparent color for the main cursor always works.
+		byte transparentColor;
+		if (id == kDefaultMystCursor) {
+			transparentColor = ((byte *)surface->getPixels())[0];
+		} else {
+			transparentColor = 255;
+		}
 		CursorMan.replaceCursor(surface->getPixels(), surface->w, surface->h, hotspotX, hotspotY, transparentColor);
 
 		// We're using the screen palette for the original game, but we need





More information about the Scummvm-git-logs mailing list